==> qtjambi-xml-5.15.3-sources.jar: io/qt/xml/QXmlSimpleReader.java <==
package io.qt.xml;


/**
 * <p>Implementation of a simple XML parser</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html">QXmlSimpleReader</a></p>
 * 
 * @deprecated Use QXmlStreamReader
 */
@Deprecated
public class QXmlSimpleReader extends io.qt.xml.QXmlReader
{
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html#QXmlSimpleReader">QXmlSimpleReader::QXmlSimpleReader()</a></p>
     */
    public QXmlSimpleReader(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlSimpleReader instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#DTDHandler">QXmlReader::DTDHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlDTDHandler DTDHandler(){
        return DTDHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlDTDHandler DTDHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#contentHandler">QXmlReader::contentHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlContentHandler contentHandler(){
        return contentHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlContentHandler contentHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#declHandler">QXmlReader::declHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlDeclHandler declHandler(){
        return declHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlDeclHandler declHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#entityResolver">QXmlReader::entityResolver()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlEntityResolver entityResolver(){
        return entityResolver_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlEntityResolver entityResolver_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#errorHandler">QXmlReader::errorHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlErrorHandler errorHandler(){
        return errorHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlErrorHandler errorHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#feature">QXmlReader::feature(QString,bool*)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Boolean feature(java.lang.String name){
        return feature_native_cref_QString_bool_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Boolean feature_native_cref_QString_bool_ptr_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#hasFeature">QXmlReader::hasFeature(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean hasFeature(java.lang.String name){
        return hasFeature_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasFeature_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#lexicalHandler">QXmlReader::lexicalHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlLexicalHandler lexicalHandler(){
        return lexicalHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlLexicalHandler lexicalHandler_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public boolean parse(io.qt.xml.QXmlInputSource input){
        return parse_native_const_QXmlInputSource_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native boolean parse_native_const_QXmlInputSource_ptr(long __this__nativeId, long input);
    
    @io.qt.QtUninvokable
    public boolean parse(io.qt.xml.QXmlInputSource input, boolean incremental){
        return parse_native_const_QXmlInputSource_ptr_bool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input), incremental);
    }
    
    @io.qt.QtUninvokable
    private native boolean parse_native_const_QXmlInputSource_ptr_bool(long __this__nativeId, long input, boolean incremental);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html#parseContinue">QXmlSimpleReader::parseContinue()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean parseContinue(){
        return parseContinue_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean parseContinue_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setContentHandler">QXmlReader::setContentHandler(QXmlContentHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setContentHandler(io.qt.xml.QXmlContentHandler handler){
        setContentHandler_native_QXmlContentHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcContentHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setContentHandler_native_QXmlContentHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setDTDHandler">QXmlReader::setDTDHandler(QXmlDTDHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setDTDHandler(io.qt.xml.QXmlDTDHandler handler){
        setDTDHandler_native_QXmlDTDHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcDTDHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setDTDHandler_native_QXmlDTDHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setDeclHandler">QXmlReader::setDeclHandler(QXmlDeclHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setDeclHandler(io.qt.xml.QXmlDeclHandler handler){
        setDeclHandler_native_QXmlDeclHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcDeclHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setDeclHandler_native_QXmlDeclHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setEntityResolver">QXmlReader::setEntityResolver(QXmlEntityResolver*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setEntityResolver(io.qt.xml.QXmlEntityResolver handler){
        setEntityResolver_native_QXmlEntityResolver_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcEntityResolver", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setEntityResolver_native_QXmlEntityResolver_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setErrorHandler">QXmlReader::setErrorHandler(QXmlErrorHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setErrorHandler(io.qt.xml.QXmlErrorHandler handler){
        setErrorHandler_native_QXmlErrorHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcErrorHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setErrorHandler_native_QXmlErrorHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setFeature">QXmlReader::setFeature(QString,bool)</a></p>
     */
    @io.qt.QtUninvokable
    public void setFeature(java.lang.String name, boolean value){
        setFeature_native_cref_QString_bool(QtJambi_LibraryUtilities.internal.nativeId(this), name, value);
    }
    
    @io.qt.QtUninvokable
    private native void setFeature_native_cref_QString_bool(long __this__nativeId, java.lang.String name, boolean value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setLexicalHandler">QXmlReader::setLexicalHandler(QXmlLexicalHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setLexicalHandler(io.qt.xml.QXmlLexicalHandler handler){
        setLexicalHandler_native_QXmlLexicalHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcLexicalHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setLexicalHandler_native_QXmlLexicalHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlSimpleReader(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-xml-5.15.8-sources.jar: io/qt/xml/QXmlSimpleReader.java <==
package io.qt.xml;


/**
 * <p>Implementation of a simple XML parser</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html">QXmlSimpleReader</a></p>
 * 
 * @deprecated Use QXmlStreamReader
 */
@Deprecated
public class QXmlSimpleReader extends io.qt.xml.QXmlReader
{
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html#QXmlSimpleReader">QXmlSimpleReader::QXmlSimpleReader()</a></p>
     */
    public QXmlSimpleReader(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlSimpleReader instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#DTDHandler">QXmlReader::DTDHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlDTDHandler DTDHandler(){
        return DTDHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlDTDHandler DTDHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#contentHandler">QXmlReader::contentHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlContentHandler contentHandler(){
        return contentHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlContentHandler contentHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#declHandler">QXmlReader::declHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlDeclHandler declHandler(){
        return declHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlDeclHandler declHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#entityResolver">QXmlReader::entityResolver()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlEntityResolver entityResolver(){
        return entityResolver_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlEntityResolver entityResolver_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#errorHandler">QXmlReader::errorHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlErrorHandler errorHandler(){
        return errorHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlErrorHandler errorHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#feature">QXmlReader::feature(QString,bool*)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Boolean feature(java.lang.String name){
        return feature_native_cref_QString_bool_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Boolean feature_native_cref_QString_bool_ptr_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#hasFeature">QXmlReader::hasFeature(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean hasFeature(java.lang.String name){
        return hasFeature_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasFeature_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#lexicalHandler">QXmlReader::lexicalHandler()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlLexicalHandler lexicalHandler(){
        return lexicalHandler_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlLexicalHandler lexicalHandler_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#parse-1">QXmlReader::parse(const QXmlInputSource*)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean parse(io.qt.xml.QXmlInputSource input){
        return parse_native_const_QXmlInputSource_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native boolean parse_native_const_QXmlInputSource_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html#parse-2">QXmlSimpleReader::parse(const QXmlInputSource*,bool)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean parse(io.qt.xml.QXmlInputSource input, boolean incremental){
        return parse_native_const_QXmlInputSource_ptr_bool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input), incremental);
    }
    
    @io.qt.QtUninvokable
    private native boolean parse_native_const_QXmlInputSource_ptr_bool(long __this__nativeId, long input, boolean incremental);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlsimplereader.html#parseContinue">QXmlSimpleReader::parseContinue()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean parseContinue(){
        return parseContinue_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean parseContinue_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setContentHandler">QXmlReader::setContentHandler(QXmlContentHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setContentHandler(io.qt.xml.QXmlContentHandler handler){
        setContentHandler_native_QXmlContentHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcContentHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setContentHandler_native_QXmlContentHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setDTDHandler">QXmlReader::setDTDHandler(QXmlDTDHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setDTDHandler(io.qt.xml.QXmlDTDHandler handler){
        setDTDHandler_native_QXmlDTDHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcDTDHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setDTDHandler_native_QXmlDTDHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setDeclHandler">QXmlReader::setDeclHandler(QXmlDeclHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setDeclHandler(io.qt.xml.QXmlDeclHandler handler){
        setDeclHandler_native_QXmlDeclHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcDeclHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setDeclHandler_native_QXmlDeclHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setEntityResolver">QXmlReader::setEntityResolver(QXmlEntityResolver*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setEntityResolver(io.qt.xml.QXmlEntityResolver handler){
        setEntityResolver_native_QXmlEntityResolver_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcEntityResolver", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setEntityResolver_native_QXmlEntityResolver_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setErrorHandler">QXmlReader::setErrorHandler(QXmlErrorHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setErrorHandler(io.qt.xml.QXmlErrorHandler handler){
        setErrorHandler_native_QXmlErrorHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcErrorHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setErrorHandler_native_QXmlErrorHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setFeature">QXmlReader::setFeature(QString,bool)</a></p>
     */
    @io.qt.QtUninvokable
    public void setFeature(java.lang.String name, boolean value){
        setFeature_native_cref_QString_bool(QtJambi_LibraryUtilities.internal.nativeId(this), name, value);
    }
    
    @io.qt.QtUninvokable
    private native void setFeature_native_cref_QString_bool(long __this__nativeId, java.lang.String name, boolean value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlreader.html#setLexicalHandler">QXmlReader::setLexicalHandler(QXmlLexicalHandler*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setLexicalHandler(io.qt.xml.QXmlLexicalHandler handler){
        setLexicalHandler_native_QXmlLexicalHandler_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(handler));
        QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.xml.QXmlReader.class, "__rcLexicalHandler", false, false, handler);
    }
    
    @io.qt.QtUninvokable
    private native void setLexicalHandler_native_QXmlLexicalHandler_ptr(long __this__nativeId, long handler);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlSimpleReader(QPrivateConstructor p) { super(p); } 
    
}
